Payment quote generation for saorsa-node.
Generates PaymentQuote values that clients use to pay for data storage.
Compatible with the autonomi payment system.
NOTE: Quote generation requires integration with the node’s signing capabilities from saorsa-core. This module provides the interface and will be fully integrated when the node is initialized.
Structs
- Quote
Generator - Quote generator for creating payment quotes.
Functions
- verify_
quote_ content - Verify a payment quote signature.